@@ -16,12 +16,11 @@
  */
 
 /*
- * $Id: XSerializationException.hpp 568078 2007-08-21 11:43:25Z amassari $
+ * $Id$
  */
 
-
-#if !defined(XSERIALIZATION_EXCEPTION_HPP)
-#define XSERIALIZATION_EXCEPTION_HPP
+#if !defined(XERCESC_INCLUDE_GUARD_XSERIALIZATION_EXCEPTION_HPP)
+#define XERCESC_INCLUDE_GUARD_XSERIALIZATION_EXCEPTION_HPP
 
 #include <xercesc/util/XercesDefs.hpp>
 #include <xercesc/util/XMLException.hpp>
